[tor-commits] [tor/master] Rename one case of c_type to c_ptr_type.

asn at torproject.org asn at torproject.org
Wed Mar 27 12:31:32 UTC 2019


commit ddb31dd58301b524564d6cc98da20e5717b05d4b
Author: Nick Mathewson <nickm at torproject.org>
Date:   Thu Mar 14 15:41:45 2019 -0400

    Rename one case of c_type to c_ptr_type.
---
 src/lib/pubsub/pubsub_macros.h | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/src/lib/pubsub/pubsub_macros.h b/src/lib/pubsub/pubsub_macros.h
index f0429dbde..d091e40df 100644
--- a/src/lib/pubsub/pubsub_macros.h
+++ b/src/lib/pubsub/pubsub_macros.h
@@ -186,17 +186,18 @@
  * It needs to be defined somewhere in Tor, using
  * "DISPATCH_REGISTER_TYPE."
  *
  * "c_type" is a C pointer type (like "char *" or "struct foo *").
  */
-#define DECLARE_MESSAGE(messagename, typename, c_type)                  \
-  DECLARE_MESSAGE_COMMON__(messagename, typename, c_type)               \
-  ATTR_UNUSED static inline c_type                                      \
+#define DECLARE_MESSAGE(messagename, typename, c_ptr_type)              \
+  DECLARE_MESSAGE_COMMON__(messagename, typename, c_ptr_type)           \
+  ATTR_UNUSED static inline c_ptr_type                                  \
   msg_arg_get__ ##messagename(msg_aux_data_t m)                         \
   {                                                                     \
     return m.ptr;                                                       \
   }                                                                     \
   ATTR_UNUSED static inline void                                        \
-  msg_arg_set__ ##messagename(msg_aux_data_t *m, c_type v)              \
+  msg_arg_set__ ##messagename(msg_aux_data_t *m, c_ptr_type v)          \
   {                                                                     \
     m->ptr = v;                                                         \
   }                                                                     \
@@ -186,17 +186,18 @@
  * "DISPATCH_REGISTER_TYPE."
  *
- * "c_type" is a C pointer type (like "char *" or "struct foo *").
+ * "c_ptr_type" is a C pointer type (like "char *" or "struct foo *").
+ * The "*" needs to be included.
  */





More information about the tor-commits mailing list